@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2011-12 Qtrac Ltd. All rights reserved.
+    Copyright © 2011-13 Qtrac Ltd. All rights reserved.
     This program or module is free software: you can redistribute it
     and/or modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation, either version 2 of
@@ -24,8 +24,8 @@
 HelpForm::HelpForm(const QString &language, QWidget *parent)
     : QMainWindow(parent)
 {
-    setAttribute(Qt::WA_DeleteOnClose);
     QTextBrowser *viewer = new QTextBrowser;
+    viewer->setOpenExternalLinks(true);
     QString filename = QString(":/help_%1.html").arg(language);
     if (!QFile::exists(filename))
         filename = ":/help.html";
